Skip to contents

Returns the number of components in the landscape graph (in this case a component is a group of patches connected by the species dispersal distance).

Usage

components.graph(rl)

Arguments

rl

Object of class 'landscape'.

Value

Returns the number of components (groups of connected patches) of a landscape.

Author

Frederico Mestre and Fernando Canovas

See also

Examples


data(rland)

components.graph(rl=rland)
#> [1] 19

#21