Skip to contents

Returns a data frame with the information on the connections between patches (assuming binary connections).

Usage

edge.graph(rl)

Arguments

rl

Object of class 'landscape'.

Value

Produces a data frame with the information on the edges (links): the IDs of both patches, the area, the coordinates and the Euclidean distance.

Author

Frederico Mestre and Fernando Canovas

See also

Examples


data(rland)

edge_df <- edge.graph(rl=rland)