Remove a given number of patches from the landscape
removepoints.RdRandomly removes a given number of patches from the landscape.
Examples
data(rland)
#Checking the number of patches in the starting landscape:
rland$number.patches
#> [1] 60
#60
#Removing 10 patches from the landscape:
rl1 <- removepoints(rl=rland, nr=10)
#Checking the number of patches in the output landscape:
rl1$number.patches
#> [1] 50
#50