Skip to contents

By loading simulatedifm this object is loaded.

Format

z.sim

nyear x nsite occupancy data generated with perfect detection.

Details

This dataset was created using the code included in Examples, in simulatedifm.