Add a given number of patches to a landscape
addpoints.RdAdds a given number of patches to the landscape.
Examples
data(rland)
#Checking the number of patches in the starting landscape:
rland$number.patches
#> [1] 60
#60
#Adding 10 patches to a landscape:
rl1 <- addpoints(rl=rland, nr=10)
#Checking the number of patches in the output landscape:
rl1$number.patches
#> [1] 70
#70