Number of components of a landscape
components.graph.RdReturns the number of components in the landscape graph (in this case a component is a group of patches connected by the species dispersal distance).
Examples
data(rland)
components.graph(rl=rland)
#> [1] 19
#21