Produce an edge (links) data frame
edge.graph.RdReturns a data frame with the information on the connections between patches (assuming binary connections).
Value
Produces a data frame with the information on the edges (links): the IDs of both patches, the area, the coordinates and the Euclidean distance.
Examples
data(rland)
edge_df <- edge.graph(rl=rland)